==> moonlight-1.20-2.16.15-fabric-sources.jar: net/mehvahdjukaar/moonlight/api/client/model/fabric/ModelWrapper.java <==
package net.mehvahdjukaar.moonlight.api.client.model.fabric;

import net.fabricmc.fabric.api.renderer.v1.render.RenderContext;
import net.mehvahdjukaar.moonlight.api.client.model.CustomBakedModel;
import net.mehvahdjukaar.moonlight.api.client.model.ExtraModelData;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_1921;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_5819;
import net.minecraft.class_777;
import net.minecraft.class_806;
import net.minecraft.class_809;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.function.Supplier;

//needed cause fabric
public final class ModelWrapper implements class_1087 {

    private final CustomBakedModel father;

    @Nullable
    private final ExtraModelData data;

    public ModelWrapper(CustomBakedModel father, @Nullable ExtraModelData data) {
        this.father = father;
        this.data = data;
    }

    @Override
    public List<class_777> method_4707(@Nullable class_2680 blockState, @Nullable class_2350 direction, class_5819 randomSource) {
        return father.getBlockQuads(blockState, direction, randomSource, class_1921.method_23581(), data);
    }

    @Override
    public boolean method_4708() {
        return father.method_4708();
    }

    @Override
    public boolean method_4712() {
        return father.method_4712();
    }

    @Override
    public boolean method_24304() {
        return father.method_24304();
    }

    @Override
    public boolean method_4713() {
        return father.method_4713();
    }

    @Override
    public class_1058 method_4711() {
        return father.getBlockParticle(data);
    }

    @Override
    public class_809 method_4709() {
        return father.method_4709();
    }

    @Override
    public class_806 method_4710() {
        return father.method_4710();
    }
}

==> moonlight-1.21-2.24.1-fabric-sources.jar: net/mehvahdjukaar/moonlight/api/client/model/fabric/ModelWrapper.java <==
package net.mehvahdjukaar.moonlight.api.client.model.fabric;

import net.fabricmc.fabric.api.renderer.v1.model.FabricBakedModel;
import net.fabricmc.fabric.api.renderer.v1.render.RenderContext;
import net.mehvahdjukaar.moonlight.api.client.model.CustomBakedModel;
import net.mehvahdjukaar.moonlight.api.client.model.ExtraModelData;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_1921;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_5819;
import net.minecraft.class_777;
import net.minecraft.class_806;
import net.minecraft.class_809;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.function.Supplier;

//needed cause fabric
public final class ModelWrapper implements class_1087, FabricBakedModel {

    private final CustomBakedModel father;

    @Nullable
    private final ExtraModelData data;

    public ModelWrapper(CustomBakedModel father, @Nullable ExtraModelData data) {
        this.father = father;
        this.data = data;
    }

    @Override
    public List<class_777> method_4707(@Nullable class_2680 blockState, @Nullable class_2350 direction, class_5819 randomSource) {
        return father.getBlockQuads(blockState, direction, randomSource, class_1921.method_23581(), data);
    }

    @Override
    public boolean method_4708() {
        return father.method_4708();
    }

    @Override
    public boolean method_4712() {
        return father.method_4712();
    }

    @Override
    public boolean method_24304() {
        return father.method_24304();
    }

    @Override
    public boolean method_4713() {
        return father.method_4713();
    }

    @Override
    public class_1058 method_4711() {
        return father.getBlockParticle(data);
    }

    @Override
    public class_809 method_4709() {
        return father.method_4709();
    }

    @Override
    public class_806 method_4710() {
        return father.method_4710();
    }
}
